@@ -95,67 +95,6 @@ class AppList {
         if (typeof cb === 'function') cb();
     }
 
-    onAppKeyPress(number) {
-        if (!this.appList[number - 1]) return;
-        this.appList[number - 1].onAppKeyPress(number);
-    }
-
-    onNewAppKeyPress(number) {
-        if (number > this.appList.length) return;
-        this.appList[number - 1].launchNewInstance();
-    }
-
-    showAppsOrder() {
-        for (let i = 0, len = this.appList.length; i < len; i++) {
-            this.appList[i].showOrderLabel(i);
-        }
-        setTimeout(() => this.calcAllWindowNumbers(), this.state.settings.showAppsOrderTimeout);
-    }
-
-    cycleMenus(r = 0) {
-        if (r > this.appList.length) {
-            this.state.set({lastCycled: -1});
-            return;
-        }
-
-        let {lastCycled} = this.state;
-        this.lastCycledTime = Date.now();
-        this.closeAllHoverMenus();
-
-        if (lastCycled < 0) {
-            lastCycled = findIndex(this.appList, (app) => {
-                return app.groupState.appId === this.listState.lastFocusedApp;
-            });
-        }
-
-        if (lastCycled < 0 || lastCycled > this.appList.length - 1) lastCycled = 0;
-
-        this.appList[lastCycled].groupState.set({thumbnailMenuEntered: true});
-        if (!this.appList[lastCycled].hoverMenu) this.appList[lastCycled].initThumbnailMenu();
-        this.appList[lastCycled].hoverMenu.open(true);
-
-        lastCycled++;
-        this.state.set({lastCycled});
-
-        if (this.appList[lastCycled - 1].groupState.metaWindows.length === 0) {
-            this.cycleMenus(r + 1);
-        }
-
-
-        let lastCycledTime = this.lastCycledTime;
-        setTimeout(() => {
-            if (lastCycledTime === this.lastCycledTime) {
-                this.state.set({lastCycled: -1});
-            }
-        }, 2000)
-    }
-
-    updateSpacing() {
-        each(this.appList, function(appGroup) {
-            appGroup.setMargin();
-        });
-    }
-
     // Gets a list of every app on the current workspace
     getSpecialApps() {
         this.specialApps = [];
@@ -182,9 +121,6 @@ class AppList {
     }
 
     loadFavorites() {
-        if (!this.state.settings.showPinned) {
-            return;
-        }
         const favorites = this.state.trigger('getFavorites');
         const appSystem = this.state.trigger('getAppSystem');
         for (let i = 0; i < favorites.length; i++) {
@@ -236,8 +172,7 @@ class AppList {
             || metaWindow.is_on_all_workspaces()
             || metaWindow.get_workspace() === this.metaWorkspace)
         && !metaWindow.is_skip_taskbar()
-        && (!this.state.settings.listMonitorWindows
-            || this.state.monitorWatchList.indexOf(metaWindow.get_monitor()) > -1);
+        && this.state.monitorWatchList.indexOf(metaWindow.get_monitor()) > -1;
     }
 
     windowAdded(metaWorkspace, metaWindow, app, isFavoriteApp) {
@@ -267,7 +202,6 @@ class AppList {
         if (!app
             || (!isFavoriteApp
                 && metaWindow
-                && this.state.settings.listMonitorWindows
                 && this.state.monitorWatchList.indexOf(metaWindow.get_monitor()) === -1)) {
             return;
         }
@@ -326,12 +260,6 @@ class AppList {
         }
     }
 
-    calcAllWindowNumbers() {
-        for (let i = 0, len = this.appList.length; i < len; i++) {
-            this.appList[i].calcWindowNumber(this.appList[i].groupState.metaWindows);
-        }
-    }
-
     updateAppGroupIndexes() {
         const newAppList = [];
         let children = this.actor.get_children();
